import * as React from 'react';

var classnames = {exports: {}};

/*!
  Copyright (c) 2018 Jed Watson.
  Licensed under the MIT License (MIT), see
  http://jedwatson.github.io/classnames
*/

(function (module) {
	/* global define */

	(function () {

		var hasOwn = {}.hasOwnProperty;

		function classNames() {
			var classes = [];

			for (var i = 0; i < arguments.length; i++) {
				var arg = arguments[i];
				if (!arg) continue;

				var argType = typeof arg;

				if (argType === 'string' || argType === 'number') {
					classes.push(arg);
				} else if (Array.isArray(arg)) {
					if (arg.length) {
						var inner = classNames.apply(null, arg);
						if (inner) {
							classes.push(inner);
						}
					}
				} else if (argType === 'object') {
					if (arg.toString === Object.prototype.toString) {
						for (var key in arg) {
							if (hasOwn.call(arg, key) && arg[key]) {
								classes.push(key);
							}
						}
					} else {
						classes.push(arg.toString());
					}
				}
			}

			return classes.join(' ');
		}

		if (module.exports) {
			classNames.default = classNames;
			module.exports = classNames;
		} else {
			window.classNames = classNames;
		}
	}());
} (classnames));

var classNames = classnames.exports;

var Breadcrumb = function (_a) {
    var className = _a.className, id = _a.id;
    return React.createElement("nav", { className: classNames('breadcrumbs', className), id: "".concat(id, "-breadcrumb-wrapper") });
};
Breadcrumb.displayName = 'Breadcrumb';

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

var getDocumentFromRef = function (ref) {
    var _a;
    var _b = React.useState(false), isClient = _b[0], setIsClient = _b[1];
    React.useEffect(function () {
        setIsClient(true);
    });
    return isClient
        ? (_a = ref.current) === null || _a === void 0 ? void 0 : _a.ownerDocument
        : undefined;
};

var getWindow = function () {
    var _a = React.useState(false), isClient = _a[0], setIsClient = _a[1];
    React.useEffect(function () {
        setIsClient(true);
    });
    return isClient
        ? window
        : undefined;
};

function useControlled(_a) {
    var controlled = _a.controlled, defaultProp = _a["default"], name = _a.name, _b = _a.state, state = _b === void 0 ? 'value' : _b;
    var isControlled = React.useRef(controlled !== undefined).current;
    var _c = React.useState(defaultProp), valueState = _c[0], setValue = _c[1];
    var value = isControlled
        ? controlled
        : valueState;
    if (process.env.NODE_ENV !== 'production') {
        React.useEffect(function () {
            if (isControlled !== (controlled !== undefined)) {
                console.error([
                    "Styless: A component is changing the ".concat(isControlled ? '' : 'un', "controlled ").concat(state, " state of ").concat(name, " to be ").concat(isControlled ? 'un' : '', "controlled."),
                    'Elements should not switch from uncontrolled to controlled (or vice versa).',
                    "Decide between using a controlled or uncontrolled ".concat(name, " ") +
                        'element for the lifetime of the component.',
                    "The nature of the state is determined during the first render. It's considered controlled if the value is not `undefined`.",
                    'More info: https://fb.me/react-controlled-components',
                ].join('\n'));
            }
        }, [state, name, controlled]);
        var defaultValue_1 = React.useRef(defaultProp).current;
        React.useEffect(function () {
            if (!isControlled && defaultValue_1 !== defaultProp) {
                console.error([
                    "Styless: A component is changing the default ".concat(state, " state of an uncontrolled ").concat(name, " after being initialized. ") +
                        "To suppress this warning opt to use a controlled ".concat(name, "."),
                ].join('\n'));
            }
        }, [JSON.stringify(defaultProp)]);
    }
    var setValueIfUncontrolled = React.useCallback(function (newValue) {
        if (!isControlled) {
            setValue(newValue);
        }
    }, []);
    return [value, setValueIfUncontrolled];
}

var useCreateBlurHandler = function (onBlur, disabled) {
    return function (event) {
        if (disabled)
            return;
        onBlur === null || onBlur === void 0 ? void 0 : onBlur(event);
    };
};

var useCreateChangeHandler = function (onChange, disabled) {
    return function (event) {
        if (disabled)
            return;
        onChange === null || onChange === void 0 ? void 0 : onChange(event);
    };
};

var useCreateClickHandler = function (onClick, disabled) {
    return function (event) {
        if (disabled)
            return;
        onClick === null || onClick === void 0 ? void 0 : onClick(event);
    };
};

var useCreateFocusHandler = function (onFocus, disabled) {
    return function (event) {
        if (disabled)
            return;
        onFocus === null || onFocus === void 0 ? void 0 : onFocus(event);
    };
};

var Button = React.forwardRef(function (_a, ref) {
    var children = _a.children, className = _a.className, _b = _a.color, color = _b === void 0 ? 'primary' : _b, _c = _a.disabled, disabled = _c === void 0 ? false : _c, _d = _a.fullWidth, fullWidth = _d === void 0 ? false : _d, onBlur = _a.onBlur, onClick = _a.onClick, onFocus = _a.onFocus, _e = _a.size, size = _e === void 0 ? 'medium' : _e, _f = _a.type, type = _f === void 0 ? 'button' : _f, _g = _a.variant, variant = _g === void 0 ? 'filled' : _g, props = __rest(_a, ["children", "className", "color", "disabled", "fullWidth", "onBlur", "onClick", "onFocus", "size", "type", "variant"]);
    var handleBlur = useCreateBlurHandler(function (event) {
        onBlur === null || onBlur === void 0 ? void 0 : onBlur(event);
    }, disabled);
    var handleClick = useCreateClickHandler(function (event) {
        onClick === null || onClick === void 0 ? void 0 : onClick(event);
    }, disabled);
    var handleFocus = useCreateFocusHandler(function (event) {
        onFocus === null || onFocus === void 0 ? void 0 : onFocus(event);
    }, disabled);
    return React.createElement("button", __assign({}, props, { className: classNames('button', color, fullWidth, size, variant, className), onBlur: handleBlur, onClick: handleClick, onFocus: handleFocus, disabled: disabled, type: type, ref: ref }), children);
});
Button.displayName = 'Button';

var Card = function (_a) {
    var children = _a.children, className = _a.className, props = __rest(_a, ["children", "className"]);
    return React.createElement("div", __assign({ className: classNames('card', className) }, props), children);
};
Card.displayName = 'Card';

var Code = function (_a) {
    var children = _a.children, className = _a.className, copyIcon = _a.copyIcon, id = _a.id, language = _a.language;
    var codeRef = React.useRef(null);
    var window = getWindow();
    var handleCopyClick = function () {
        var code = codeRef.current.innerHTML;
        window.navigator.clipboard.writeText(code);
    };
    return React.createElement("div", { className: classNames('code-root', className), id: "".concat(id, "-code-root") },
        React.createElement("div", { className: 'code-header', id: "".concat(id, "-code-header") },
            React.createElement("span", null, language),
            React.createElement("button", { className: 'code-copy-button', onClick: handleCopyClick }, copyIcon)),
        React.createElement("code", { className: 'code-content', id: "".concat(id, "-code-content"), ref: codeRef }, children));
};
Code.displayName = 'Code';

var Error = function (_a) {
    var children = _a.children, id = _a.id;
    return React.createElement("span", { "aria-live": 'polite', id: id, role: 'region' }, children);
};
Error.displayName = 'Error';

var Hint = function (_a) {
    var children = _a.children, id = _a.id;
    return React.createElement("span", { id: id }, children);
};
Hint.displayName = 'Hint';

var IconButton = React.forwardRef(function (_a, ref) {
    var className = _a.className, icon = _a.icon, props = __rest(_a, ["className", "icon"]);
    return React.createElement(Button, __assign({}, props, { className: classNames('icon-button', className), ref: ref }), icon);
});
IconButton.displayName = 'IconButton';

var Image = function (_a) {
    var alt = _a.alt, className = _a.className, src = _a.src;
    return React.createElement("figure", { className: 'image-wrapper' },
        React.createElement("img", { alt: alt, className: classNames('image', className), src: src }),
        React.createElement("figcaption", { className: 'image-caption' }, alt));
};
Image.displayName = 'Image';

var Link = React.forwardRef(function (_a, ref) {
    var children = _a.children, className = _a.className, href = _a.href, onBlur = _a.onBlur, onClick = _a.onClick, onFocus = _a.onFocus, _b = _a.variant, variant = _b === void 0 ? 'link' : _b, props = __rest(_a, ["children", "className", "href", "onBlur", "onClick", "onFocus", "variant"]);
    if (process.env.ENVIRONMENT !== 'production') {
        if (!href.startsWith('http://') || !href.startsWith('https://')) {
            console.error("\n                DS: links require their href prop to start with either http:// or https://.\n            ");
        }
    }
    var handleBlur = useCreateBlurHandler(function (event) {
        onBlur === null || onBlur === void 0 ? void 0 : onBlur(event);
    }, false);
    var handleClick = useCreateClickHandler(function (event) {
        onClick === null || onClick === void 0 ? void 0 : onClick(event);
    }, false);
    var handleFocus = useCreateFocusHandler(function (event) {
        onFocus === null || onFocus === void 0 ? void 0 : onFocus(event);
    }, false);
    return React.createElement("a", __assign({}, props, { className: classNames('link', variant, className), href: href, onBlur: handleBlur, onClick: handleClick, onFocus: handleFocus, ref: ref }), children);
});
Link.displayName = 'Link';

var ListItem = function (_a) {
    var children = _a.children, className = _a.className, props = __rest(_a, ["children", "className"]);
    return React.createElement("li", __assign({ className: classNames('list-item', className) }, props), children);
};
ListItem.displayName = 'ListItem';

var OrderedList = function (_a) {
    var children = _a.children, className = _a.className, props = __rest(_a, ["children", "className"]);
    return React.createElement("ul", __assign({ className: classNames('ordered-list', className) }, props), children);
};
OrderedList.displayName = 'OrderedList';

var Typography = function (_a) {
    var children = _a.children, className = _a.className, _b = _a.variant, variant = _b === void 0 ? 'p' : _b, props = __rest(_a, ["children", "className", "variant"]);
    return React.createElement(variant, __assign(__assign({}, props), { className: classNames('typography', variant, className) }), children);
};
Typography.displayName = 'Typography';

var UnorderedList = function (_a) {
    var children = _a.children, className = _a.className, props = __rest(_a, ["children", "className"]);
    return React.createElement("ul", __assign({ className: classNames('unordered-list', className) }, props), children);
};
UnorderedList.displayName = 'UnorderedList';

export { Breadcrumb, Button, Card, Code, Error, Hint, IconButton, Image, Link, ListItem, OrderedList, Typography, UnorderedList, getDocumentFromRef, getWindow, useControlled, useCreateBlurHandler, useCreateChangeHandler, useCreateClickHandler, useCreateFocusHandler };
