import * as React from 'react';

interface BreadcrumbProps {
    className?: string;
    id?: string;
    url: string;
}
declare const Breadcrumb: React.FC<BreadcrumbProps>;

/**
 *
 */
declare type color = 'primary' | 'secondary' | 'tertiary';
/**
 *
 */
declare type size = 'large' | 'medium' | 'small';

declare type ButtonOmitProps = 'size';
interface ButtonProps extends Omit<React.HTMLAttributes<HTMLButtonElement>, ButtonOmitProps> {
    /**
     * The color of the button.
     *
     * Default value: 'primary'
     */
    color?: color;
    /**
     * Makes the button non-interactive.
     *
     * Default value: false
     */
    disabled?: boolean;
    /**
     * Makes the button take 100% of the parent's width.
     *
     * Default value: false
     */
    fullWidth?: boolean;
    /**
     * Adds a class to the button based on the size prop's value.
     *
     * Default value: 'medium'
     */
    size?: size;
    type?: 'button' | 'submit' | 'reset';
    /**
     * Controls the style of the button.
     *
     * Default value: 'solid'
     */
    variant?: 'filled' | 'outlined' | 'text';
}
declare const Button: React.ForwardRefExoticComponent<ButtonProps & React.RefAttributes<HTMLButtonElement>>;

interface CardProps extends React.HTMLAttributes<HTMLDivElement> {
}
declare const Card: React.FC<CardProps>;

interface CodeProps {
    children?: string;
    className?: string;
    copyIcon: React.ReactNode;
    id: string;
    language?: string;
}
declare const Code: React.FC<CodeProps>;

interface ErrorProps {
    children?: React.ReactNode;
    id: string;
}
declare const Error: React.FC<ErrorProps>;

interface HintProps {
    children?: React.ReactNode;
    id: string;
}
declare const Hint: React.FC<HintProps>;

interface IconButtonProps extends ButtonProps {
    icon: React.ReactNode;
}
declare const IconButton: React.ForwardRefExoticComponent<IconButtonProps & React.RefAttributes<HTMLButtonElement>>;

interface ImageProps extends React.HTMLAttributes<HTMLImageElement> {
    alt: string;
    src: string;
}
declare const Image: React.FC<ImageProps>;

interface LinkProps extends React.HTMLAttributes<HTMLAnchorElement> {
    /**
     *
     */
    href: string;
    /**
     *
     */
    variant?: 'link' | 'button';
}
declare const Link: React.ForwardRefExoticComponent<LinkProps & React.RefAttributes<HTMLAnchorElement>>;

interface ListItemProps extends React.HTMLAttributes<HTMLLIElement> {
}
declare const ListItem: React.FC<ListItemProps>;

interface OrderedListProps extends React.HTMLAttributes<HTMLOListElement> {
}
declare const OrderedList: React.FC<OrderedListProps>;

declare type TypographyElements = HTMLHeadingElement | HTMLParagraphElement;

interface TypographyProps extends React.HTMLAttributes<TypographyElements> {
    variant?: 'h1' | 'h2' | 'h3' | 'h4' | 'h5' | 'h6' | 'p';
}
declare const Typography: React.FC<TypographyProps>;

interface UnorderedListProps extends React.HTMLAttributes<HTMLUListElement> {
}
declare const UnorderedList: React.FC<UnorderedListProps>;

declare type TextareaOmitProps = 'name';
interface TextareaProps extends Omit<React.HTMLAttributes<HTMLTextAreaElement>, TextareaOmitProps> {
    disabled?: boolean;
    error?: string;
    hint?: string;
    label: string;
    name: string;
}

declare const getDocumentFromRef: <ElementType extends HTMLElement>(ref: React.MutableRefObject<ElementType>) => Document | undefined;

declare const getWindow: () => Window | undefined;

interface UseControlledProps<ValueType> {
    controlled: ValueType;
    default: ValueType;
    name: string;
    state?: string;
}
declare function useControlled<ValueType>({ controlled, default: defaultProp, name, state }: UseControlledProps<ValueType>): [ValueType, (newValue: ValueType) => void];

declare const useCreateBlurHandler: <ElementType>(onBlur: (event: React.FocusEvent<ElementType, Element>) => void, disabled: boolean) => (event: React.FocusEvent<ElementType, Element>) => void;

declare const useCreateChangeHandler: <ElementType>(onChange: (event: React.ChangeEvent<ElementType>) => void, disabled: boolean) => (event: React.ChangeEvent<ElementType>) => void;

declare const useCreateClickHandler: <ElementType>(onClick: (event: React.MouseEvent<ElementType, MouseEvent>) => void, disabled: boolean) => (event: React.MouseEvent<ElementType, MouseEvent>) => void;

declare const useCreateFocusHandler: <ElementType>(onFocus: (event: React.FocusEvent<ElementType, Element>) => void, disabled: boolean) => (event: React.FocusEvent<ElementType, Element>) => void;

export { Breadcrumb, BreadcrumbProps, Button, ButtonProps, Card, CardProps, Code, CodeProps, Error, ErrorProps, Hint, HintProps, IconButton, IconButtonProps, Image, ImageProps, Link, LinkProps, ListItem, ListItemProps, OrderedList, OrderedListProps, TextareaProps, Typography, TypographyProps, UnorderedList, UnorderedListProps, getDocumentFromRef, getWindow, useControlled, useCreateBlurHandler, useCreateChangeHandler, useCreateClickHandler, useCreateFocusHandler };
